@@ -4,6 +4,7 @@ from flask import Blueprint, send_from_directory
 from flask_restful import Api, Resource
 
 from aim.web.app.projects.project import Project
+from aim.web.app.utils import send_from_directory_gzip_compressed
 
 general_bp = Blueprint('general', __name__)
 general_api = Api(general_bp)
@@ -12,15 +13,15 @@ general_api = Api(general_bp)
 def serve_wrong_urls(e):
     from aim.web.run import application
     static_dir = os.path.join(os.path.dirname(application.root_path), 'ui', 'build')
-    return send_from_directory(static_dir, 'index.html'), 200
+    return send_from_directory_gzip_compressed(static_dir, 'index.html'), 200
 
 
 @general_api.resource('/')
 class ServeMainPage(Resource):
-    def get(self, path=None):
+    def get(self):
         from aim.web.run import application
         static_dir = os.path.join(os.path.dirname(application.root_path), 'ui', 'build')
-        return send_from_directory(static_dir, 'index.html')
+        return send_from_directory_gzip_compressed(static_dir, 'index.html')
 
 
 @general_api.resource('/static-files/<path:path>')
@@ -28,7 +29,7 @@ class ServeStaticFiles(Resource):
     def get(self, path):
         from aim.web.run import application
         static_dir = os.path.join(os.path.dirname(application.root_path), 'ui', 'build')
-        return send_from_directory(static_dir, path)
+        return send_from_directory_gzip_compressed(static_dir, path)
 
 
 @general_api.resource('/static/<exp_name>/<commit_hash>/media/images/<path>')
